.. :changelog:

History
-------

0.1.0 (2013-11-08)
++++++++++++++++++

* First release on PyPI.

0.1.1 (2013-11-10)
++++++++++++++++++

* Makes this app more extendable by using custom models and forms

0.1.2 (2013-12-04)
++++++++++++++++++

* Exports registered users to CSV from admin panel
* Create newsletters from admin panel
* Fixed installation from pip

0.1.3 (2013-12-04)
++++++++++++++++++

* Bugfixed circular imports when setting custom Forms
